# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CheckExistsResponse(UniversalBaseModel):
    """
    Response with existing and new record IDs.
    """

    existing_ids: typing.List[str] = pydantic.Field()
    """
    IDs that already exist in the system
    """

    new_ids: typing.List[str] = pydantic.Field()
    """
    IDs that are new and don't exist yet
    """

    total_checked: int = pydantic.Field()
    """
    Total number of IDs checked
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
