# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .model_compatibility_response import ModelCompatibilityResponse
from .tool_parameter_response import ToolParameterResponse


class ToolCapabilitiesResponse(UniversalBaseModel):
    """
    Tool capabilities and configuration options.
    """

    modes: typing.List[str] = pydantic.Field()
    """
    Available configuration modes (e.g., ['on', 'off', 'auto'])
    """

    parameters: typing.List[ToolParameterResponse] = pydantic.Field()
    """
    Available configuration parameters for this tool
    """

    model_compatibility: typing_extensions.Annotated[
        ModelCompatibilityResponse,
        FieldMetadata(alias="modelCompatibility"),
        pydantic.Field(alias="modelCompatibility", description="Which model types this tool is compatible with"),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
