# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AttachmentSummary(UniversalBaseModel):
    """
    Summary of an attachment for inclusion in rule details.
    """

    id: str = pydantic.Field()
    """
    Attachment ID
    """

    entity_type: str = pydantic.Field()
    """
    Entity type
    """

    entity_id: str = pydantic.Field()
    """
    Entity ID
    """

    priority: int = pydantic.Field()
    """
    Priority
    """

    character_limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Character limit
    """

    is_active: bool = pydantic.Field()
    """
    Whether attachment is active
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
