# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class IntelligenceFeatures(UniversalBaseModel):
    """
    Advanced analysis features.
    """

    sentiment_analysis_enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Enable sentiment analysis
    """

    entity_detection_enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Enable entity detection
    """

    auto_highlights_enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Enable automatic highlights
    """

    summarization_enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Enable summarization
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
