# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .date_filter import DateFilter
from .llm_mode import LlmMode


class BatchScrapeOptions(UniversalBaseModel):
    """
    Options for batch scraping operations.
    """

    max_items_per_url: typing.Optional[int] = pydantic.Field(default=None)
    """
    Max items per URL
    """

    max_total_items: typing.Optional[int] = pydantic.Field(default=None)
    """
    Max total items across all URLs
    """

    parallel_jobs: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of parallel scraping jobs
    """

    timeout_per_url: typing.Optional[int] = pydantic.Field(default=None)
    """
    Timeout per URL in seconds
    """

    date_filter: typing.Optional[DateFilter] = pydantic.Field(default=None)
    """
    Filter items by date
    """

    llm_mode: typing.Optional[LlmMode] = pydantic.Field(default=None)
    """
    LLM processing mode
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
