# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DailyApiKeyUsage(UniversalBaseModel):
    """
    Daily API key usage data.
    """

    date: str = pydantic.Field()
    """
    Date (YYYY-MM-DD)
    """

    requests: int = pydantic.Field()
    """
    API key requests count
    """

    cost: float = pydantic.Field()
    """
    API key cost in CHF
    """

    synapses: float = pydantic.Field()
    """
    Total synapses
    """

    neurons: float = pydantic.Field()
    """
    Total neurons
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
