# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CoachingScoreResponse(UniversalBaseModel):
    """
    Response for a coaching scorecard.
    """

    id: str
    organization_id: str
    session_id: str
    user_id: typing.Optional[str] = None
    framework: str
    overall_score: typing.Optional[float] = None
    criteria_scores: typing.Dict[str, typing.Any]
    strengths: typing.Optional[typing.List[str]] = None
    improvements: typing.Optional[typing.List[str]] = None
    created_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
