# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CalendarConnectionResponse(UniversalBaseModel):
    """
    Response schema for a calendar connection.
    """

    credential_id: str
    provider: str
    account_email: typing.Optional[str] = None
    is_active: bool
    last_sync_at: typing.Optional[dt.datetime] = None
    event_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
