# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .recent_decision import RecentDecision


class DecisionsResponse(UniversalBaseModel):
    """
    Decision tracking aggregated from intelligence.
    """

    total_decisions: int
    avg_decisions_per_meeting: float
    meetings_with_decisions: int
    meetings_without_decisions: int
    recent_decisions: typing.Optional[typing.List[RecentDecision]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
