# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConfigSelectOption(UniversalBaseModel):
    """
    A selectable option for multi_select or dropdown fields.
    """

    value: str = pydantic.Field()
    """
    Value to submit
    """

    label: str = pydantic.Field()
    """
    Display label
    """

    group: typing.Optional[str] = pydantic.Field(default=None)
    """
    Group name for visual grouping
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Secondary description text
    """

    selected: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether pre-selected by default
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
