# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ApiKeyUsageDetail(UniversalBaseModel):
    """
    Detailed usage information for a specific API key.
    """

    api_key_id: str = pydantic.Field()
    """
    API key ID
    """

    api_key_name: str = pydantic.Field()
    """
    API key name
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    month: int = pydantic.Field()
    """
    Month (1-12)
    """

    year: int = pydantic.Field()
    """
    Year
    """

    usage: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Usage metrics
    """

    limit: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Limit information
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
