# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .audit_log_schema import AuditLogSchema
from .pagination_schema import PaginationSchema


class AppApiV1SchemasAssistantsAuditLogListResponse(UniversalBaseModel):
    """
    Response schema for audit log list.
    """

    audit_logs: typing.List[AuditLogSchema] = pydantic.Field()
    """
    List of audit logs
    """

    pagination: PaginationSchema = pydantic.Field()
    """
    Pagination info
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
