# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .participant_duration import ParticipantDuration
from .session_participant_event import SessionParticipantEvent


class SessionParticipantsResponse(UniversalBaseModel):
    """
    Participant detail for a single session.
    """

    session_id: str
    current_participants: typing.Optional[typing.List[str]] = None
    timeline: typing.Optional[typing.List[SessionParticipantEvent]] = None
    participant_durations: typing.Optional[typing.List[ParticipantDuration]] = None
    peak_participants: typing.Optional[int] = None
    peak_timestamp: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
