# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .breakdown_item import BreakdownItem


class BreakdownResponse(UniversalBaseModel):
    """
    Breakdown of sessions by a dimension.
    """

    dimension: str = pydantic.Field()
    """
    What was broken down (platform, status, ...)
    """

    total: int
    items: typing.Optional[typing.List[BreakdownItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
