# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class NeuronsTrendsResponse(UniversalBaseModel):
    """
    Response model for trends analysis (supports neurons, synapses, or combined).
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    metric: typing.Optional[str] = pydantic.Field(default=None)
    """
    Metric type analyzed: 'neurons', 'synapses', 'all', or null
    """

    period: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Analysis period
    """

    trends: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Trend analysis data
    """

    patterns: typing.List[typing.Dict[str, typing.Any]] = pydantic.Field()
    """
    Identified patterns
    """

    forecasts: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Trend forecasts
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
