# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ActionItemResponse(UniversalBaseModel):
    """
    Response schema for an action item.
    """

    id: str
    intelligence_id: str
    session_id: str
    organization_id: str
    title: str
    description: typing.Optional[str] = None
    assignee_hint: typing.Optional[str] = None
    assigned_to: typing.Optional[str] = None
    due_date: typing.Optional[dt.date] = None
    priority: str
    status: str
    source_timestamp: typing.Optional[dt.datetime] = None
    source_quote: typing.Optional[str] = None
    routed_to: typing.Optional[str] = None
    external_task_id: typing.Optional[str] = None
    external_task_url: typing.Optional[str] = None
    routing_status: typing.Optional[str] = None
    routing_error: typing.Optional[str] = None
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
