# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AddToVectorStoreResponse(UniversalBaseModel):
    """
    Response schema for add-to-vector-store operation.
    """

    session_id: str
    vector_store_id: str
    file_id: str
    vector_store_file_id: str
    status: str = pydantic.Field()
    """
    Processing status: pending, processing, completed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
