# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DealTimelineEntry(UniversalBaseModel):
    """
    A single session entry in a deal timeline.
    """

    session_id: str
    risk_score: typing.Optional[float] = None
    risk_factors: typing.Optional[typing.List[str]] = None
    buying_signals: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    objections: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    next_steps: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    pricing_discussed: typing.Optional[bool] = None
    created_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
