# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VectorStoreUsageItem(UniversalBaseModel):
    """
    Individual vector store usage.
    """

    vector_store_id: str = pydantic.Field()
    """
    Vector store ID
    """

    vector_store_name: str = pydantic.Field()
    """
    Vector store name
    """

    data_size_bytes: int = pydantic.Field()
    """
    Storage size in bytes
    """

    data_size_mb: float = pydantic.Field()
    """
    Storage size in MB
    """

    file_count: int = pydantic.Field()
    """
    Number of files
    """

    usage_percentage: float = pydantic.Field()
    """
    Percentage of total organization usage
    """

    color: str = pydantic.Field()
    """
    Color for UI visualization
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
