# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .reasoning_effort_option import ReasoningEffortOption
from .summary_option import SummaryOption


class ModelReasoningOptionsResponse(UniversalBaseModel):
    """
    Response schema for model reasoning options.
    """

    model_key: str = pydantic.Field()
    """
    The model key queried
    """

    reasoning_supported: bool = pydantic.Field()
    """
    Whether the model supports reasoning
    """

    effort_options: typing.Optional[typing.List[ReasoningEffortOption]] = pydantic.Field(default=None)
    """
    Available reasoning effort levels
    """

    summary_options: typing.Optional[typing.List[SummaryOption]] = pydantic.Field(default=None)
    """
    Available reasoning summary levels
    """

    default_effort: typing.Optional[str] = pydantic.Field(default=None)
    """
    Default reasoning effort level
    """

    default_summary: typing.Optional[str] = pydantic.Field(default=None)
    """
    Default reasoning summary level
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
