# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AutoJoinRuleResponse(UniversalBaseModel):
    """
    Response schema for an auto-join rule.
    """

    id: str
    name: str
    is_enabled: bool
    calendar_provider: typing.Optional[str] = None
    match_mode: str
    keywords: typing.Optional[typing.List[str]] = None
    organizer_emails: typing.Optional[typing.List[str]] = None
    exclude_patterns: typing.Optional[typing.List[str]] = None
    min_attendees: int
    max_attendees: typing.Optional[int] = None
    time_window_start: typing.Optional[str] = None
    time_window_end: typing.Optional[str] = None
    days_of_week: typing.Optional[typing.List[int]] = None
    timezone: str
    bot_name: typing.Optional[str] = None
    priority: int
    destination_vector_store_id: typing.Optional[str] = None
    auto_add_to_vector_store: typing.Optional[bool] = None
    participation_mode: typing.Optional[str] = None
    voice_profile_id: typing.Optional[str] = None
    auto_share_mode: typing.Optional[str] = None
    auto_share_department_ids: typing.Optional[typing.List[str]] = None
    attendee_emails: typing.Optional[typing.List[str]] = None
    assistant_id: typing.Optional[str] = None
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
