# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VectorStoreResponse(UniversalBaseModel):
    """
    Schema for vector store response.
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the vector store
    """

    name: str = pydantic.Field()
    """
    Human-readable name for the vector store
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Brief description of the vector store's purpose and contents
    """

    organization_id: str = pydantic.Field()
    """
    The organization this vector store belongs to
    """

    created_by: str = pydantic.Field()
    """
    User ID of the person who created this vector store
    """

    created_at: dt.datetime = pydantic.Field()
    """
    ISO 8601 timestamp when the vector store was created
    """

    updated_at: dt.datetime = pydantic.Field()
    """
    ISO 8601 timestamp when the vector store was last modified
    """

    is_active: bool = pydantic.Field()
    """
    Whether the vector store is active and available for use
    """

    access_mode: str = pydantic.Field()
    """
    Access control for the vector store
    """

    access_departments: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Array of department IDs that have access to this vector store
    """

    access_users: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Array of user IDs with explicit access to this vector store
    """

    file_count: int = pydantic.Field()
    """
    Number of files currently stored in this vector store
    """

    data_size: int = pydantic.Field()
    """
    Total size of all files in bytes
    """

    flowplate_project_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Flow-plate project ID for organizational scoping
    """

    flow_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Flow-plate flow ID for flow-level scoping
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
