# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .app_api_v1schemas_meeting_buddy_analytics_topic_item import AppApiV1SchemasMeetingBuddyAnalyticsTopicItem


class TopicsResponse(UniversalBaseModel):
    """
    Top topics aggregated from intelligence records.
    """

    topics: typing.Optional[typing.List[AppApiV1SchemasMeetingBuddyAnalyticsTopicItem]] = None
    total_unique_topics: int
    total_sessions_with_topics: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
