# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AudioModelInfo(UniversalBaseModel):
    """
    Information about an available audio model.
    """

    key: str = pydantic.Field()
    """
    Model key used in API requests
    """

    name: str = pydantic.Field()
    """
    Human-readable model name
    """

    category: str = pydantic.Field()
    """
    Model category (stt, diarization, speaker_id, emotion, topic, tts)
    """

    is_default: bool = pydantic.Field()
    """
    Whether this is the default model for its category
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
