# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .grant_path_entry_response import GrantPathEntryResponse


class UserAccessEntryResponse(UniversalBaseModel):
    """
    A user's access to a specific entity.
    """

    user_id: str
    access_level: str
    grant_paths: typing.Optional[typing.List[GrantPathEntryResponse]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
