# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .store_file_list_item import StoreFileListItem


class StoreFileListResponse(UniversalBaseModel):
    """
    Paginated list of files in a store.
    """

    items: typing.List[StoreFileListItem] = pydantic.Field()
    """
    Files in this page
    """

    total: int = pydantic.Field()
    """
    Total number of files
    """

    skip: int = pydantic.Field()
    """
    Offset
    """

    limit: int = pydantic.Field()
    """
    Page size
    """

    has_more: bool = pydantic.Field()
    """
    Whether more results exist
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
