# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .ui_access_actions import UiAccessActions
from .ui_access_pages import UiAccessPages


class UiAccessResponse(UniversalBaseModel):
    """
    Response body for the UI access manifest endpoint.
    """

    user_id: str
    organization_id: str
    pages: UiAccessPages
    actions: UiAccessActions

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
