# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .vector_store_file_response import VectorStoreFileResponse


class VectorStoreFileListResponse(UniversalBaseModel):
    """
    Schema for paginated list of files in vector store.
    """

    total: int = pydantic.Field()
    """
    Total number of files in the vector store
    """

    page: int = pydantic.Field()
    """
    Current page number
    """

    page_size: int = pydantic.Field()
    """
    Number of items per page
    """

    total_pages: int = pydantic.Field()
    """
    Total number of pages
    """

    files: typing.List[VectorStoreFileResponse] = pydantic.Field()
    """
    List of files in the current page
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
