# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AccessGrantResponse(UniversalBaseModel):
    """
    Schema for access grant response.
    """

    id: str
    entity_type: str
    entity_id: str
    grantee_type: str
    grantee_id: str
    grantee_name: typing.Optional[str] = None
    grantee_email: typing.Optional[str] = None
    access_level: str
    granted_by: str
    granted_by_name: typing.Optional[str] = None
    organization_id: str
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
