# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.calendar_connection_response import CalendarConnectionResponse
from ...types.connect_calendar_o_auth_response import ConnectCalendarOAuthResponse

ConnectCalendarResponse = typing.Union[ConnectCalendarOAuthResponse, CalendarConnectionResponse]
