# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.system_tools_list_response import SystemToolsListResponse


class RawToolsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list_system_tools(
        self,
        *,
        include_capabilities: typing.Optional[bool] = None,
        category: typing.Optional[str] = None,
        model_compatibility: typing.Optional[str] = None,
        visible_in_ui: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SystemToolsListResponse]:
        """
        List available built-in Freddy AI system tools.

        Supports both authentication methods:
        - Bearer token: Use Authorization header with user token
        - API key: Use X-API-Key header with organization API key

        Query Parameters:
            include_capabilities: Include detailed tool capabilities (default: True)
            category: Filter tools by category (search, computation, generation, automation, analysis)
            model_compatibility: Filter by model type compatibility (text, vision, voice, multimodal)
            visible_in_ui: Filter by UI visibility (true = only UI-visible tools, false = only hidden tools, null = all)

        Returns:
            SystemToolsListResponse with list of tools and total count

        Parameters
        ----------
        include_capabilities : typing.Optional[bool]

        category : typing.Optional[str]

        model_compatibility : typing.Optional[str]

        visible_in_ui : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SystemToolsListResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/toolbox/system-tools",
            method="GET",
            params={
                "include_capabilities": include_capabilities,
                "category": category,
                "model_compatibility": model_compatibility,
                "visible_in_ui": visible_in_ui,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SystemToolsListResponse,
                    parse_obj_as(
                        type_=SystemToolsListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawToolsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list_system_tools(
        self,
        *,
        include_capabilities: typing.Optional[bool] = None,
        category: typing.Optional[str] = None,
        model_compatibility: typing.Optional[str] = None,
        visible_in_ui: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SystemToolsListResponse]:
        """
        List available built-in Freddy AI system tools.

        Supports both authentication methods:
        - Bearer token: Use Authorization header with user token
        - API key: Use X-API-Key header with organization API key

        Query Parameters:
            include_capabilities: Include detailed tool capabilities (default: True)
            category: Filter tools by category (search, computation, generation, automation, analysis)
            model_compatibility: Filter by model type compatibility (text, vision, voice, multimodal)
            visible_in_ui: Filter by UI visibility (true = only UI-visible tools, false = only hidden tools, null = all)

        Returns:
            SystemToolsListResponse with list of tools and total count

        Parameters
        ----------
        include_capabilities : typing.Optional[bool]

        category : typing.Optional[str]

        model_compatibility : typing.Optional[str]

        visible_in_ui : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SystemToolsListResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/toolbox/system-tools",
            method="GET",
            params={
                "include_capabilities": include_capabilities,
                "category": category,
                "model_compatibility": model_compatibility,
                "visible_in_ui": visible_in_ui,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SystemToolsListResponse,
                    parse_obj_as(
                        type_=SystemToolsListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
