# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class LimitsSummary(UniversalBaseModel):
    """
    Summary statistics for limits.
    """

    total_keys: int = pydantic.Field()
    """
    Total number of API keys
    """

    keys_with_limits: int = pydantic.Field()
    """
    Number of keys with limits configured
    """

    keys_exceeded: int = pydantic.Field()
    """
    Number of keys that exceeded limits
    """

    overall_status: str = pydantic.Field()
    """
    Overall status: ok, warning, exceeded
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
