# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ChunkedUploadResponse(UniversalBaseModel):
    """
    Response schema for chunked upload URL.
    """

    upload_id: str = pydantic.Field()
    """
    Generated File ID for registration
    """

    signed_url: str = pydantic.Field()
    """
    Resumable upload session URI
    """

    chunk_size: int = pydantic.Field()
    """
    Recommended chunk size in bytes
    """

    expires_at: dt.datetime = pydantic.Field()
    """
    Session expiry
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
