# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .store_usage_entry import StoreUsageEntry


class StorageUsageResponse(UniversalBaseModel):
    """
    Response schema for storage usage across stores.
    """

    total_bytes: int = pydantic.Field()
    """
    Total storage capacity in bytes
    """

    used_bytes: int = pydantic.Field()
    """
    Total bytes used
    """

    file_count: int = pydantic.Field()
    """
    Total number of files
    """

    stores: typing.List[StoreUsageEntry] = pydantic.Field()
    """
    Per-store breakdown
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
