# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class TopicResponse(UniversalBaseModel):
    """
    Response schema for a session topic segment.
    """

    id: str
    topic: str
    start_ms: int
    end_ms: int
    keywords: typing.Optional[typing.List[str]] = None
    summary: typing.Optional[str] = None
    order: typing.Optional[int] = None
    transcript_count: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
