# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SystemToolSchema(UniversalBaseModel):
    """
    System tool configuration schema.
    """

    mode: typing.Optional[str] = pydantic.Field(default=None)
    """
    Tool mode: on, off, auto
    """

    sources: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include sources
    """

    outputs: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include outputs
    """

    results: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include results
    """

    image_url: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include image URLs
    """

    provider: typing.Optional[str] = pydantic.Field(default=None)
    """
    Provider
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
