# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .api_key_usage_summary import ApiKeyUsageSummary
from .daily_api_key_usage import DailyApiKeyUsage


class ApiKeyDailyUsageResponse(UniversalBaseModel):
    """
    API key daily usage response.
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    period: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Time period info
    """

    daily_usage: typing.List[DailyApiKeyUsage] = pydantic.Field()
    """
    Daily usage data
    """

    summary: ApiKeyUsageSummary = pydantic.Field()
    """
    Usage summary
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
