# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ModelCompatibilityResponse(UniversalBaseModel):
    """
    Model type compatibility configuration.
    """

    text: bool = pydantic.Field()
    """
    Compatible with text-only models
    """

    vision: bool = pydantic.Field()
    """
    Compatible with vision-capable models
    """

    voice: bool = pydantic.Field()
    """
    Compatible with voice models
    """

    multimodal: bool = pydantic.Field()
    """
    Compatible with multimodal models
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
