# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .reasoning_config_schema_effort import ReasoningConfigSchemaEffort
from .reasoning_config_schema_summary import ReasoningConfigSchemaSummary


class ReasoningConfigSchema(UniversalBaseModel):
    """
    Reasoning configuration schema.
    """

    effort: typing.Optional[ReasoningConfigSchemaEffort] = pydantic.Field(default=None)
    """
    Reasoning effort: off, low, medium, high, maximum
    """

    summary: typing.Optional[ReasoningConfigSchemaSummary] = pydantic.Field(default=None)
    """
    Summary level: off (no formatting), auto, concise, detailed. Note: Claude ignores this field.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
