# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ActiveSessionSummary(UniversalBaseModel):
    """
    Summary of a currently active meeting buddy session.
    """

    session_id: str
    meeting_link: str
    platform: str
    status: str
    bot_name: str
    join_timestamp: typing.Optional[dt.datetime] = None
    current_participants: typing.Optional[typing.List[str]] = None
    duration_so_far_seconds: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
