# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ImapConnectionResponse(UniversalBaseModel):
    """
    Response for IMAP connection.
    """

    credential_id: str = pydantic.Field()
    """
    Credential ID
    """

    email_address: str = pydantic.Field()
    """
    Connected email address
    """

    message: str = pydantic.Field()
    """
    Success message
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
