# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class TranscriptSegment(UniversalBaseModel):
    """
    Response schema for transcript segment.
    """

    transcript_id: str
    text: str
    confidence: typing.Optional[float] = None
    start_time: float
    end_time: float
    speaker: typing.Optional[str] = None
    speaker_display_name: typing.Optional[str] = None
    language_code: str
    created_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
