# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class IntelligenceConfigResponse(UniversalBaseModel):
    """
    Response schema for an intelligence config.
    """

    id: str
    organization_id: str
    user_id: typing.Optional[str] = None
    name: str
    is_default: bool
    prompts: typing.List[typing.Dict[str, typing.Any]]
    model_override: typing.Optional[str] = None
    output_sections: typing.List[str]
    meeting_type_filter: typing.Optional[typing.List[str]] = None
    auto_vector_store_id: typing.Optional[str] = None
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
