# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .top_assignee import TopAssignee


class ActionItemsOverviewResponse(UniversalBaseModel):
    """
    Action item health metrics across the organization.
    """

    total_action_items: int
    by_status: typing.Optional[typing.Dict[str, int]] = None
    by_priority: typing.Optional[typing.Dict[str, int]] = None
    completion_rate: float
    avg_per_meeting: float
    top_assignees: typing.Optional[typing.List[TopAssignee]] = None
    routed_count: int
    routing_breakdown: typing.Optional[typing.Dict[str, int]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
