# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class FiltersAppliedSchema(UniversalBaseModel):
    """
    Applied filters schema.
    """

    search: typing.Optional[str] = pydantic.Field(default=None)
    """
    Search term
    """

    access_mode: typing.Optional[str] = pydantic.Field(default=None)
    """
    Access mode filter
    """

    include_inactive: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include inactive assistants
    """

    sort_by: typing.Optional[str] = pydantic.Field(default=None)
    """
    Sort field
    """

    sort_order: typing.Optional[str] = pydantic.Field(default=None)
    """
    Sort order
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
