# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .assistant_list_response_assistants_item import AssistantListResponseAssistantsItem
from .filters_applied_schema import FiltersAppliedSchema
from .pagination_schema import PaginationSchema
from .user_context_schema import UserContextSchema


class AssistantListResponse(UniversalBaseModel):
    """
    Response schema for assistant list.
    """

    assistants: typing.List[AssistantListResponseAssistantsItem] = pydantic.Field()
    """
    List of assistants
    """

    total: int = pydantic.Field()
    """
    Total number of assistants
    """

    organization_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Organization ID
    """

    pagination: PaginationSchema = pydantic.Field()
    """
    Pagination info
    """

    filters_applied: FiltersAppliedSchema = pydantic.Field()
    """
    Applied filters
    """

    user_context: UserContextSchema = pydantic.Field()
    """
    User context
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
