# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .deal_timeline_entry import DealTimelineEntry


class DealTimelineResponse(UniversalBaseModel):
    """
    Multi-meeting timeline for a deal.
    """

    deal_id: str
    deal_name: typing.Optional[str] = None
    entries: typing.List[DealTimelineEntry]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
