# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class NeuronsBenchmarksResponse(UniversalBaseModel):
    """
    Response model for benchmarks (supports neurons, synapses, or combined).
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    metric: typing.Optional[str] = pydantic.Field(default=None)
    """
    Metric type analyzed: 'neurons', 'synapses', 'all', or null
    """

    benchmarks: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Performance benchmarks
    """

    comparisons: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Industry comparisons
    """

    rankings: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Performance rankings
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
