# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .connection_info import ConnectionInfo


class CompleteOAuthResponse(UniversalBaseModel):
    """
    Response after completing an OAuth flow.
    """

    connected: bool = pydantic.Field()
    """
    Whether the connection was established
    """

    connection: typing.Optional[ConnectionInfo] = pydantic.Field(default=None)
    """
    Connection info if connected
    """

    connector_status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Raw connector connection status
    """

    message: str = pydantic.Field()
    """
    Human-readable status message
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
