# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .mini_chat_settings_payload import MiniChatSettingsPayload


class MiniChatSettingsData(UniversalBaseModel):
    """
    Inner data envelope returned to the client.
    """

    settings: MiniChatSettingsPayload = pydantic.Field()
    """
    Normalized settings
    """

    revision: int = pydantic.Field()
    """
    Monotonic revision counter
    """

    updated_at: typing_extensions.Annotated[
        dt.datetime,
        FieldMetadata(alias="updatedAt"),
        pydantic.Field(alias="updatedAt", description="Last update timestamp (ISO 8601 UTC)"),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
