# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .mcp_tool_schema import McpToolSchema
from .system_tool_schema import SystemToolSchema


class ToolConfigurationSchema(UniversalBaseModel):
    """
    Tool configuration schema.
    """

    system_tools: typing.Optional[typing.Dict[str, typing.Optional[SystemToolSchema]]] = pydantic.Field(default=None)
    """
    System tools configuration
    """

    mcp_tools: typing.Optional[typing.List[McpToolSchema]] = pydantic.Field(default=None)
    """
    MCP tools configuration
    """

    streamline_tools: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Streamline automation IDs
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
