# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SpeakerDetail(UniversalBaseModel):
    """
    Detailed speaking statistics for a single speaker.
    """

    speaker: str
    total_speaking_seconds: float
    total_word_count: int
    segment_count: int
    session_count: int
    avg_words_per_minute: float
    avg_confidence: float
    longest_monologue_seconds: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
