# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .execution_log_entry import ExecutionLogEntry


class ExecutionLogsResponse(UniversalBaseModel):
    """
    Response for execution logs listing.
    """

    logs: typing.List[ExecutionLogEntry] = pydantic.Field()
    """
    List of execution logs
    """

    total: int = pydantic.Field()
    """
    Total number of logs matching filters
    """

    returned: int = pydantic.Field()
    """
    Number of logs returned
    """

    has_more: bool = pydantic.Field()
    """
    Whether more logs are available
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
