# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UiAccessPages(UniversalBaseModel):
    """
    Boolean flags for UI page visibility.
    """

    organization: typing.Optional[bool] = None
    my_team: typing.Optional[bool] = None
    departments: typing.Optional[bool] = None
    roles: typing.Optional[bool] = None
    audit_log: typing.Optional[bool] = None
    billing: typing.Optional[bool] = None
    knowledge: typing.Optional[bool] = None
    spaces: typing.Optional[bool] = None
    members: typing.Optional[bool] = None
    meetings: typing.Optional[bool] = None
    my_access: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
