# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class NeuronsAnalyticsDashboardResponse(UniversalBaseModel):
    """
    Response model for analytics dashboard (supports neurons, synapses, or combined).
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    metric: typing.Optional[str] = pydantic.Field(default=None)
    """
    Metric type analyzed: 'neurons', 'synapses', 'all', or null
    """

    period: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Analysis period information
    """

    current_summary: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Current period summary metrics
    """

    daily_trends: typing.List[typing.Dict[str, typing.Any]] = pydantic.Field()
    """
    Daily usage trends
    """

    usage_patterns: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Usage pattern analysis
    """

    efficiency_metrics: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Efficiency and optimization metrics
    """

    predictions: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Predictive projections
    """

    insights: typing.List[typing.Dict[str, typing.Any]] = pydantic.Field()
    """
    AI-generated insights and recommendations
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
