# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class RecordingInfoResponse(UniversalBaseModel):
    """
    Recording metadata for a session.
    """

    session_id: str
    output_directory: typing.Optional[str] = None
    segment_count: typing.Optional[int] = None
    audio_file_count: typing.Optional[int] = None
    video_file_count: typing.Optional[int] = None
    total_size_bytes: typing.Optional[int] = None
    total_duration_seconds: typing.Optional[float] = None
    has_recording: typing.Optional[bool] = None
    video_url: typing.Optional[str] = None
    video_duration_seconds: typing.Optional[float] = None
    video_resolution: typing.Optional[str] = None
    video_fps: typing.Optional[int] = None
    video_size_bytes: typing.Optional[int] = None
    video_format: typing.Optional[str] = None
    video_codec: typing.Optional[str] = None
    video_quality_tier: typing.Optional[str] = None
    video_cost_estimate: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
