# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .streamline_git_sync_job_response import StreamlineGitSyncJobResponse


class StreamlineGitSyncJobListResponse(UniversalBaseModel):
    """
    Schema for git sync job list response.
    """

    sync_jobs: typing.List[StreamlineGitSyncJobResponse]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
