# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .confidence_trend_point import ConfidenceTrendPoint


class QualityMetricsResponse(UniversalBaseModel):
    """
    Transcription and recording quality metrics.
    """

    avg_transcription_confidence: float
    confidence_trend: typing.Optional[typing.List[ConfidenceTrendPoint]] = None
    language_distribution: typing.Optional[typing.Dict[str, int]] = None
    avg_words_per_session: float
    avg_segments_per_session: float
    pii_redaction_usage: typing.Optional[typing.Dict[str, int]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
