# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AssistantMbpConfigResponse(UniversalBaseModel):
    """
    Response schema for assistant MBP configuration.
    """

    id: str
    assistant_id: str
    organization_id: str
    join_mode: str
    is_enabled: bool
    bot_name_override: typing.Optional[str] = None
    trigger_patterns: typing.Optional[typing.List[str]] = None
    respond_to_direct_messages: bool
    respond_to_group_mentions: bool
    auto_join_rule_ids: typing.Optional[typing.List[str]] = None
    allowed_tool_categories: typing.Optional[typing.List[str]] = None
    max_response_time_seconds: int
    meeting_summary_enabled: bool
    transcription_enabled: bool
    follow_user_ids: typing.Optional[typing.List[str]] = None
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
