# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class FileContentResponse(UniversalBaseModel):
    """
    Response schema for file content URL.
    """

    file_id: str = pydantic.Field()
    """
    File ID
    """

    filename: str = pydantic.Field()
    """
    Original filename
    """

    mime_type: str = pydantic.Field()
    """
    File MIME type
    """

    file_size: int = pydantic.Field()
    """
    File size in bytes
    """

    download_url: str = pydantic.Field()
    """
    Signed download URL (valid for 1 hour)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
