# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .deal_summary_response import DealSummaryResponse


class DealListResponse(UniversalBaseModel):
    """
    Paginated list of tracked deals.
    """

    deals: typing.List[DealSummaryResponse]
    total: int
    page: int
    page_size: int
    total_pages: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
