# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class BriefingResponse(UniversalBaseModel):
    """
    Pre-meeting briefing for an upcoming event.
    """

    event_id: str
    briefing_text: str
    deal_id: typing.Optional[str] = None
    deal_name: typing.Optional[str] = None
    past_session_count: typing.Optional[int] = None
    open_action_items: typing.Optional[int] = None
    generated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
