# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DealTrackingResponse(UniversalBaseModel):
    """
    Response for deal tracking data.
    """

    id: str
    organization_id: str
    session_id: str
    deal_id: typing.Optional[str] = None
    deal_name: typing.Optional[str] = None
    crm_provider: typing.Optional[str] = None
    risk_score: typing.Optional[float] = None
    risk_factors: typing.Optional[typing.List[str]] = None
    buying_signals: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    objections: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    next_steps: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    pricing_discussed: typing.Optional[bool] = None
    pricing_details: typing.Optional[typing.Dict[str, typing.Any]] = None
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
