# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.add_to_vector_store_response import AddToVectorStoreResponse
from .raw_client import AsyncRawMeetingBuddyVectorStoreRoutingClient, RawMeetingBuddyVectorStoreRoutingClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class MeetingBuddyVectorStoreRoutingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawMeetingBuddyVectorStoreRoutingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawMeetingBuddyVectorStoreRoutingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawMeetingBuddyVectorStoreRoutingClient
        """
        return self._raw_client

    def add_meeting_buddy_session_to_vector_store(
        self, session_id: str, *, vector_store_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AddToVectorStoreResponse:
        """
        Formats the session's transcript and intelligence as a searchable document and adds it to the specified vector store for embedding.

        Parameters
        ----------
        session_id : str

        vector_store_id : str
            Target vector store ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddToVectorStoreResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.meeting_buddy_vector_store_routing.add_meeting_buddy_session_to_vector_store(
            session_id="session_id",
            vector_store_id="vector_store_id",
        )
        """
        _response = self._raw_client.add_meeting_buddy_session_to_vector_store(
            session_id, vector_store_id=vector_store_id, request_options=request_options
        )
        return _response.data


class AsyncMeetingBuddyVectorStoreRoutingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawMeetingBuddyVectorStoreRoutingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawMeetingBuddyVectorStoreRoutingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawMeetingBuddyVectorStoreRoutingClient
        """
        return self._raw_client

    async def add_meeting_buddy_session_to_vector_store(
        self, session_id: str, *, vector_store_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AddToVectorStoreResponse:
        """
        Formats the session's transcript and intelligence as a searchable document and adds it to the specified vector store for embedding.

        Parameters
        ----------
        session_id : str

        vector_store_id : str
            Target vector store ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddToVectorStoreResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.meeting_buddy_vector_store_routing.add_meeting_buddy_session_to_vector_store(
                session_id="session_id",
                vector_store_id="vector_store_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_meeting_buddy_session_to_vector_store(
            session_id, vector_store_id=vector_store_id, request_options=request_options
        )
        return _response.data
