# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .action_item_response import ActionItemResponse


class IntelligenceResponse(UniversalBaseModel):
    """
    Response schema for meeting intelligence.
    """

    id: str
    session_id: str
    organization_id: str
    executive_summary: typing.Optional[str] = None
    detailed_summary: typing.Optional[str] = None
    key_topics: typing.Optional[typing.List[str]] = None
    sentiment: typing.Optional[str] = None
    sentiment_details: typing.Optional[typing.Dict[str, typing.Any]] = None
    decisions: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    follow_up_questions: typing.Optional[typing.List[str]] = None
    meeting_type: typing.Optional[str] = None
    extraction_model: typing.Optional[str] = None
    extraction_tokens_used: typing.Optional[int] = None
    extraction_cost_cents: typing.Optional[int] = None
    status: str
    error_message: typing.Optional[str] = None
    action_items: typing.Optional[typing.List[ActionItemResponse]] = None
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
