# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .participant_stat import ParticipantStat


class ParticipantsResponse(UniversalBaseModel):
    """
    Participant statistics across sessions.
    """

    total_unique_participants: int
    avg_participants_per_session: float
    max_participants_in_session: int
    top_participants: typing.Optional[typing.List[ParticipantStat]] = None
    sessions_with_participants: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
