# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class WorkflowTriggerResponse(UniversalBaseModel):
    """
    Response schema for a workflow trigger.
    """

    id: str
    organization_id: str
    name: str
    event_type: str
    workflow_id: str
    conditions: typing.Dict[str, typing.Any]
    is_enabled: bool
    description: typing.Optional[str] = None
    execution_count: typing.Optional[int] = None
    last_executed_at: typing.Optional[dt.datetime] = None
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
