# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConnectorInfo(UniversalBaseModel):
    """
    Available connector information for the /available endpoint.
    """

    id: str = pydantic.Field()
    """
    Unique connector identifier
    """

    tool_key: str = pydantic.Field()
    """
    Tool key identifier (e.g., 'slack', 'github')
    """

    display_name: str = pydantic.Field()
    """
    Human-readable display name
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Tool description
    """

    category: typing.Optional[str] = pydantic.Field(default=None)
    """
    Tool category (e.g., 'communication', 'development')
    """

    icon_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to tool icon/logo
    """

    app_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Link to the tool's application website
    """

    is_connected: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether user has connected this tool
    """

    connection_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Connection ID if connected
    """

    release_channel: typing.Optional[str] = pydantic.Field(default=None)
    """
    Release channel: 'stable' for Aitronos-auth connectors, 'beta' for partner-auth connectors
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
