# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UsageSummaryResponse(UniversalBaseModel):
    """
    Response model for overall usage summary.
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    total_requests: int = pydantic.Field()
    """
    Total number of requests
    """

    total_synapses: float = pydantic.Field()
    """
    Total synapses (input + output)
    """

    total_neurons: float = pydantic.Field()
    """
    Total neurons
    """

    total_cost: float = pydantic.Field()
    """
    Total cost in CHF
    """

    average_cost_per_request: float = pydantic.Field()
    """
    Average cost per request
    """

    top_models: typing.List[typing.Dict[str, typing.Any]] = pydantic.Field()
    """
    Most used models
    """

    time_range: typing.Dict[str, str] = pydantic.Field()
    """
    Time range of the data
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
