# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .vector_store_usage_item import VectorStoreUsageItem


class VectorStoreUsageResponse(UniversalBaseModel):
    """
    Vector store usage summary for organization.
    """

    total_size_bytes: int = pydantic.Field()
    """
    Total storage used in bytes
    """

    total_size_mb: float = pydantic.Field()
    """
    Total storage used in MB
    """

    total_files: int = pydantic.Field()
    """
    Total number of files
    """

    vector_store_count: int = pydantic.Field()
    """
    Number of vector stores
    """

    vector_stores: typing.List[VectorStoreUsageItem] = pydantic.Field()
    """
    Usage breakdown by vector store
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
