# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DeviceSessionResponse(UniversalBaseModel):
    """
    Response schema for device session.
    """

    id: str = pydantic.Field()
    """
    Device session ID with dsess_ prefix
    """

    device_id: str
    device_name: typing.Optional[str] = None
    platform: typing.Optional[str] = None
    operating_system: typing.Optional[str] = None
    location: typing.Optional[str] = None
    is_active: bool
    last_used_at: dt.datetime
    created_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
