# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class StreamlineExecutionResponse(UniversalBaseModel):
    """
    Schema for execution response.
    """

    id: str
    automation_id: str
    organization_id: str
    triggered_by_user_id: typing.Optional[str] = None
    trigger_method: str
    parameters: typing.Optional[typing.Dict[str, typing.Any]] = None
    status: str
    started_at: typing.Optional[dt.datetime] = None
    completed_at: typing.Optional[dt.datetime] = None
    duration_seconds: typing.Optional[int] = None
    result: typing.Optional[typing.Dict[str, typing.Any]] = None
    error_message: typing.Optional[str] = None
    logs: typing.Optional[str] = None
    created_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
