# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .api_key_create_response import ApiKeyCreateResponse


class ApiKeyRotateResponse(UniversalBaseModel):
    """
    Response schema for API key rotation (includes new raw key ONCE).
    """

    success: bool = pydantic.Field()
    """
    Whether rotation succeeded
    """

    message: str = pydantic.Field()
    """
    Rotation result message
    """

    old_key_id: str = pydantic.Field()
    """
    ID of the old (deleted) key
    """

    new_key: ApiKeyCreateResponse = pydantic.Field()
    """
    New key details with raw key
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
