# This file was auto-generated by Fern from our API Definition.

import typing

RuleScope = typing.Union[
    typing.Literal["global", "organization", "model", "assistant", "user", "vector_store"], typing.Any
]
