# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class KnowledgeVectorStoreResponse(UniversalBaseModel):
    """
    Schema for vector store response in knowledge context.
    """

    id: str
    name: str
    description: typing.Optional[str] = None
    slice_id: typing.Optional[str] = None
    slice_ids: typing.Optional[typing.List[str]] = None
    organization_id: str
    created_by: str
    is_active: bool
    access_mode: str
    file_count: int
    data_size: int
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
