# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .public_transcript_segment import PublicTranscriptSegment


class PublicTranscriptResponse(UniversalBaseModel):
    """
    Response for public transcript page -- no auth required.
    """

    session_title: typing.Optional[str] = None
    session_date: dt.datetime
    duration_seconds: typing.Optional[float] = None
    platform: typing.Optional[str] = None
    participant_count: typing.Optional[int] = None
    transcript_segments: typing.Optional[typing.List[PublicTranscriptSegment]] = None
    executive_summary: typing.Optional[str] = None
    detailed_summary: typing.Optional[str] = None
    key_topics: typing.Optional[typing.List[str]] = None
    decisions: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    action_items: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = None
    chat_enabled: typing.Optional[bool] = None
    chat_messages_remaining: typing.Optional[int] = None
    chat_thread_id: typing.Optional[str] = None
    shared_by_org: typing.Optional[str] = None
    is_live: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
