# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class WorkflowUpdate(UniversalBaseModel):
    """
    Schema for updating a workflow.
    """

    name: typing.Optional[str] = None
    description: typing.Optional[str] = None
    definition: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Updated workflow definition
    """

    is_active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Active status
    """

    external_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Flow-plate internal flow ID for correlation
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
