# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .supported_file_category import SupportedFileCategory
from .unsupported_file_category import UnsupportedFileCategory


class FileUploadConfigResponse(UniversalBaseModel):
    """
    Response schema for file upload configuration.
    """

    direct_upload_max_bytes: int
    chunked_upload_chunk_bytes: int
    supported_types: typing.Dict[str, SupportedFileCategory]
    unsupported_categories: typing.List[UnsupportedFileCategory]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
