# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AttachmentDeleteResponse(UniversalBaseModel):
    """
    Response schema for attachment deletion.
    """

    message: str = pydantic.Field()
    """
    Confirmation message
    """

    rule_id: str = pydantic.Field()
    """
    Rule ID
    """

    entity_type: str = pydantic.Field()
    """
    Entity type
    """

    entity_id: str = pydantic.Field()
    """
    Entity ID
    """

    detached_at: dt.datetime = pydantic.Field()
    """
    Timestamp when entity was detached
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
