# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .data_export_action_item import DataExportActionItem
from .data_export_consent_record import DataExportConsentRecord
from .data_export_intelligence import DataExportIntelligence
from .data_export_session import DataExportSession
from .data_export_transcript import DataExportTranscript


class DataExportResponse(UniversalBaseModel):
    """
    Full GDPR data export response.
    """

    user_id: str
    organization_id: str
    sessions: typing.List[DataExportSession]
    transcripts: typing.List[DataExportTranscript]
    intelligence: typing.List[DataExportIntelligence]
    action_items: typing.List[DataExportActionItem]
    consent_records: typing.List[DataExportConsentRecord]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
