# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConfidenceMetrics(UniversalBaseModel):
    """
    Confidence metrics for extraction quality.
    """

    image_analysis: int = pydantic.Field()
    """
    Confidence in image/text quality (0-100)
    """

    data_extraction: int = pydantic.Field()
    """
    Confidence in data extraction accuracy (0-100)
    """

    validation: int = pydantic.Field()
    """
    Confidence in schema validation (0-100)
    """

    overall: int = pydantic.Field()
    """
    Overall confidence score (0-100)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
