# This file was auto-generated by Fern from our API Definition.

import typing

RuleType = typing.Union[
    typing.Literal["behavior", "guardrails", "formatting", "context", "content_policy", "constraint"], typing.Any
]
