# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .failure_item import FailureItem


class FailureAnalysisResponse(UniversalBaseModel):
    """
    Failure breakdown with error codes and rates.
    """

    total_failed: int
    failure_rate: float = pydantic.Field()
    """
    Failed / total sessions
    """

    items: typing.Optional[typing.List[FailureItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
