# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawMeetingBuddyStreamingClient, RawMeetingBuddyStreamingClient


class MeetingBuddyStreamingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawMeetingBuddyStreamingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawMeetingBuddyStreamingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawMeetingBuddyStreamingClient
        """
        return self._raw_client

    def stream_meeting_buddy_session(
        self, session_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Server-Sent Events stream for real-time session status updates, participant joins/leaves, and error notifications.

        Parameters
        ----------
        session_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.meeting_buddy_streaming.stream_meeting_buddy_session(
            session_id="session_id",
        )
        """
        _response = self._raw_client.stream_meeting_buddy_session(session_id, request_options=request_options)
        return _response.data

    def stream_meeting_buddy_transcripts(
        self, session_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Server-Sent Events stream for real-time transcript segments. Includes both partial (in-progress) and final transcripts.

        Parameters
        ----------
        session_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.meeting_buddy_streaming.stream_meeting_buddy_transcripts(
            session_id="session_id",
        )
        """
        _response = self._raw_client.stream_meeting_buddy_transcripts(session_id, request_options=request_options)
        return _response.data

    def stream_meeting_buddy_logs(
        self, session_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Server-Sent Events stream for diagnostic log entries. Useful for debugging bot connection issues in real time.

        Parameters
        ----------
        session_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.meeting_buddy_streaming.stream_meeting_buddy_logs(
            session_id="session_id",
        )
        """
        _response = self._raw_client.stream_meeting_buddy_logs(session_id, request_options=request_options)
        return _response.data


class AsyncMeetingBuddyStreamingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawMeetingBuddyStreamingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawMeetingBuddyStreamingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawMeetingBuddyStreamingClient
        """
        return self._raw_client

    async def stream_meeting_buddy_session(
        self, session_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Server-Sent Events stream for real-time session status updates, participant joins/leaves, and error notifications.

        Parameters
        ----------
        session_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.meeting_buddy_streaming.stream_meeting_buddy_session(
                session_id="session_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.stream_meeting_buddy_session(session_id, request_options=request_options)
        return _response.data

    async def stream_meeting_buddy_transcripts(
        self, session_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Server-Sent Events stream for real-time transcript segments. Includes both partial (in-progress) and final transcripts.

        Parameters
        ----------
        session_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.meeting_buddy_streaming.stream_meeting_buddy_transcripts(
                session_id="session_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.stream_meeting_buddy_transcripts(session_id, request_options=request_options)
        return _response.data

    async def stream_meeting_buddy_logs(
        self, session_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        Server-Sent Events stream for diagnostic log entries. Useful for debugging bot connection issues in real time.

        Parameters
        ----------
        session_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.meeting_buddy_streaming.stream_meeting_buddy_logs(
                session_id="session_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.stream_meeting_buddy_logs(session_id, request_options=request_options)
        return _response.data
