# This file was auto-generated by Fern from our API Definition.

import typing

MiniChatPosition = typing.Union[
    typing.Literal["bottom-right", "bottom-left", "top-right", "top-left", "bottom-center", "top-center"], typing.Any
]
