# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .coaching_score_response import CoachingScoreResponse
from .competitor_mention_response import CompetitorMentionResponse
from .deal_tracking_response import DealTrackingResponse


class RevenueIntelligenceResponse(UniversalBaseModel):
    """
    Full revenue intelligence for a session.
    """

    session_id: str
    deal_tracking: typing.Optional[DealTrackingResponse] = None
    competitor_mentions: typing.Optional[typing.List[CompetitorMentionResponse]] = None
    coaching_scores: typing.Optional[typing.List[CoachingScoreResponse]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
