# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DepartmentMemberResponse(UniversalBaseModel):
    """
    Member of a department.
    """

    user_id: str
    full_name: typing.Optional[str] = None
    email: str
    account_state: typing.Optional[str] = None
    role_ids: typing.Optional[typing.List[str]] = None
    added_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
