# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OrgSettingsResponse(UniversalBaseModel):
    """
    Response for org-level Meeting Buddy settings.
    """

    auto_share_link_in_chat: typing.Optional[bool] = None
    public_chat_enabled: typing.Optional[bool] = None
    public_chat_message_limit: typing.Optional[int] = None
    public_chat_model: typing.Optional[str] = None
    share_link_expiry_days: typing.Optional[int] = None
    chat_agent_enabled: typing.Optional[bool] = None
    chat_agent_name: typing.Optional[str] = None
    greeting_enabled: typing.Optional[bool] = None
    greeting_message: typing.Optional[str] = None
    farewell_enabled: typing.Optional[bool] = None
    farewell_include_summary: typing.Optional[bool] = None
    email_enabled: typing.Optional[bool] = None
    email_recipients: typing.Optional[str] = None
    email_custom_recipients: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
