# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .sentiment_data_point import SentimentDataPoint
from .sentiment_overall import SentimentOverall


class SentimentTrendsResponse(UniversalBaseModel):
    """
    Sentiment trends over time.
    """

    data_points: typing.Optional[typing.List[SentimentDataPoint]] = None
    overall: typing.Optional[SentimentOverall] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
