# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UserV2Response(UniversalBaseModel):
    """
    Response body for User V2 endpoints.
    """

    id: str
    full_name: typing.Optional[str] = None
    email: str
    user_name: typing.Optional[str] = None
    account_state: str
    role_ids: typing.Optional[typing.List[str]] = None
    department_ids: typing.Optional[typing.List[str]] = None
    organization_id: str
    invitation_link: typing.Optional[str] = None
    invited_at: typing.Optional[str] = None
    deactivated_at: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
