# This file was auto-generated by Fern from our API Definition.

import typing

from .assistant_response import AssistantResponse
from .assistant_standard_response import AssistantStandardResponse
from .assistant_summary_response import AssistantSummaryResponse

AssistantListResponseAssistantsItem = typing.Union[
    AssistantSummaryResponse, AssistantStandardResponse, AssistantResponse
]
