# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ComposioSyncStatusResponse(UniversalBaseModel):
    """
    Response schema for connector sync status endpoint.
    """

    total_tools: int
    enabled_tools: int
    last_sync_at: typing.Optional[str] = None
    next_sync_at: typing.Optional[str] = None
    sync_interval_hours: int
    incremental_sync_enabled: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
