# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .session_speaker_detail import SessionSpeakerDetail


class SessionSpeakerBreakdownResponse(UniversalBaseModel):
    """
    Per-session speaker breakdown with silence tracking.
    """

    session_id: str
    total_duration_seconds: float
    speakers: typing.Optional[typing.List[SessionSpeakerDetail]] = None
    silence_seconds: float
    silence_percentage: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
