# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UserBriefResponse(UniversalBaseModel):
    """
    Brief user info included in auth responses.
    """

    id: str = pydantic.Field()
    """
    User ID (prefixed with 'usr_')
    """

    email: str = pydantic.Field()
    """
    User email address
    """

    username: typing.Optional[str] = pydantic.Field(default=None)
    """
    Username
    """

    verified: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether email is verified
    """

    current_organization_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Currently active organization ID
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
