# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class PiiSettingsResponse(UniversalBaseModel):
    """
    Response schema for PII redaction settings.
    """

    organization_id: str
    redaction_mode: str = pydantic.Field()
    """
    none, on_export, or always
    """

    categories: typing.List[str] = pydantic.Field()
    """
    Active PII categories for redaction
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
