# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConsentRecordResponse(UniversalBaseModel):
    """
    Response schema for a consent record.
    """

    id: str
    session_id: str
    participant_name: str
    consent_status: str = pydantic.Field()
    """
    implicit, explicit, or declined
    """

    method: str = pydantic.Field()
    """
    implicit, chat_prompt, or voice_prompt
    """

    announced_at: typing.Optional[dt.datetime] = None
    responded_at: typing.Optional[dt.datetime] = None
    created_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
