# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConnectionTestResult(UniversalBaseModel):
    """
    Result of MCP connection test.
    """

    success: bool = pydantic.Field()
    """
    Whether connection was successful
    """

    status: str = pydantic.Field()
    """
    Connection status
    """

    message: str = pydantic.Field()
    """
    Result message
    """

    available_tools: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of available tool names
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
