# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError


class RawWebhooksClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def connector_webhook(
        self,
        *,
        composio_signature: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Any]:
        """
        Receive and process connector trigger webhooks.

        The platform sends webhooks for trigger events like:
        - New email received (Gmail)
        - New calendar event (Google Calendar)
        - New message in channel (Slack)
        - New issue created (GitHub)
        - And 500+ other triggers

        The webhook payload contains:
        - trigger_id: Unique identifier for the trigger
        - trigger_name: Name of the trigger (e.g., "gmail_new_email")
        - connection_id: ID of the connected account
        - payload: Event-specific data

        Security:
        - Signature verification using HMAC-SHA256

        Returns:
            200: Webhook received and processed successfully
            401: Invalid signature
            422: Invalid payload
            500: Processing error

        Parameters
        ----------
        composio_signature : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Any]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/webhooks/composio",
            method="POST",
            headers={
                "x-composio-signature": str(composio_signature) if composio_signature is not None else None,
            },
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawWebhooksClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def connector_webhook(
        self,
        *,
        composio_signature: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Any]:
        """
        Receive and process connector trigger webhooks.

        The platform sends webhooks for trigger events like:
        - New email received (Gmail)
        - New calendar event (Google Calendar)
        - New message in channel (Slack)
        - New issue created (GitHub)
        - And 500+ other triggers

        The webhook payload contains:
        - trigger_id: Unique identifier for the trigger
        - trigger_name: Name of the trigger (e.g., "gmail_new_email")
        - connection_id: ID of the connected account
        - payload: Event-specific data

        Security:
        - Signature verification using HMAC-SHA256

        Returns:
            200: Webhook received and processed successfully
            401: Invalid signature
            422: Invalid payload
            500: Processing error

        Parameters
        ----------
        composio_signature : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Any]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/webhooks/composio",
            method="POST",
            headers={
                "x-composio-signature": str(composio_signature) if composio_signature is not None else None,
            },
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Any,
                    parse_obj_as(
                        type_=typing.Any,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
