# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .document_extract_response import DocumentExtractResponse


class BatchExtractResponse(UniversalBaseModel):
    """
    Response model for batch document extraction.
    """

    success: bool = pydantic.Field()
    """
    Whether the batch request was successful
    """

    batch_id: str = pydantic.Field()
    """
    Batch ID for tracking
    """

    total_documents: int = pydantic.Field()
    """
    Total number of documents in batch
    """

    jobs: typing.List[DocumentExtractResponse] = pydantic.Field()
    """
    List of individual job responses
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
