# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .change_log_response import ChangeLogResponse


class ChangeLogListResponse(UniversalBaseModel):
    """
    Schema for paginated change log list.
    """

    logs: typing.List[ChangeLogResponse] = pydantic.Field()
    """
    List of change logs
    """

    total_count: int = pydantic.Field()
    """
    Total number of logs
    """

    skip: int = pydantic.Field()
    """
    Number of records skipped
    """

    take: int = pydantic.Field()
    """
    Number of records returned
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
