# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class KnowledgeVectorStoreCreate(UniversalBaseModel):
    """
    Schema for creating a vector store within a knowledge slice.
    """

    name: str
    description: typing.Optional[str] = None
    access_mode: typing.Optional[str] = None
    access_target_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Target ID for department/user/group access modes
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
