# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class TrendDataPoint(UniversalBaseModel):
    """
    Single data point in a time-series trend.
    """

    period: str = pydantic.Field()
    """
    Period label (e.g., '2026-02-15' or '2026-W07')
    """

    session_count: typing.Optional[int] = None
    completed_count: typing.Optional[int] = None
    failed_count: typing.Optional[int] = None
    total_duration_hours: typing.Optional[float] = None
    avg_duration_minutes: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
