# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .slice_access_entry import SliceAccessEntry
from .store_access_entry import StoreAccessEntry


class ResolvedAccessResponse(UniversalBaseModel):
    """
    Full resolved access response for a user.
    """

    user_id: str
    resolved_at: dt.datetime
    slice_access: typing.Optional[typing.List[SliceAccessEntry]] = None
    store_access: typing.Optional[typing.List[StoreAccessEntry]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
