# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SpaceVectorStoreEntry(UniversalBaseModel):
    """
    Response for an additional vector store attached to a space.
    """

    id: str = pydantic.Field()
    """
    Link ID (svs_ prefix)
    """

    vector_store_id: str = pydantic.Field()
    """
    Vector store ID
    """

    added_by: str = pydantic.Field()
    """
    User ID who added this
    """

    added_at: dt.datetime = pydantic.Field()
    """
    When added
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
