# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .thread_response import ThreadResponse


class SpaceThreadListResponse(UniversalBaseModel):
    """
    Response for listing threads in a space.
    """

    object: typing.Optional[str] = pydantic.Field(default=None)
    """
    Object type
    """

    data: typing.List[ThreadResponse] = pydantic.Field()
    """
    List of thread objects
    """

    has_more: bool = pydantic.Field()
    """
    Whether more results are available
    """

    next_cursor: typing.Optional[str] = pydantic.Field(default=None)
    """
    Cursor for next page
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
